@@ -18,7 +18,7 @@ class MemoryDataMessage(Message):
         Message.__init__(self)
         self.high_address = 0x00
         self.low_address = 0x00
-        self.data = bytes([])
+        self.data = 0
         self.set_defaults(address)
 
     def populate(self, priority, address, rtr, data):
@@ -38,7 +38,7 @@ class MemoryDataMessage(Message):
         """
         :return: bytes
         """
-        return bytes([COMMAND_CODE, self.high_address, self.low_address]) + self.data
+        return bytes([COMMAND_CODE, self.high_address, self.low_address, self.data])
 
     def to_json(self):
         """
